svn commit: r257499 - head/sys/netinet

Gleb Smirnoff glebius at FreeBSD.org
Fri Nov 1 10:18:42 UTC 2013


Author: glebius
Date: Fri Nov  1 10:18:41 2013
New Revision: 257499
URL: http://svnweb.freebsd.org/changeset/base/257499

Log:
  Cleanup in_ifscrub(), which is just an entry to in_scrubprefix().

Modified:
  head/sys/netinet/if_ether.c
  head/sys/netinet/in.c
  head/sys/netinet/in_var.h
  head/sys/netinet/raw_ip.c

Modified: head/sys/netinet/if_ether.c
==============================================================================
--- head/sys/netinet/if_ether.c	Fri Nov  1 10:01:57 2013	(r257498)
+++ head/sys/netinet/if_ether.c	Fri Nov  1 10:18:41 2013	(r257499)
@@ -142,7 +142,7 @@ static const struct netisr_handler arp_n
 
 #ifdef AF_INET
 /*
- * called by in_ifscrub to remove entry from the table when
+ * called by in_scrubprefix() to remove entry from the table when
  * the interface goes away
  */
 void

Modified: head/sys/netinet/in.c
==============================================================================
--- head/sys/netinet/in.c	Fri Nov  1 10:01:57 2013	(r257498)
+++ head/sys/netinet/in.c	Fri Nov  1 10:18:41 2013	(r257499)
@@ -488,7 +488,7 @@ in_control(struct socket *so, u_long cmd
 			 * is the same as before, then the call is
 			 * un-necessarily executed here.
 			 */
-			in_ifscrub(ifp, ia, LLE_STATIC);
+			in_scrubprefix(ia, LLE_STATIC);
 			ia->ia_sockmask = ifra->ifra_mask;
 			ia->ia_sockmask.sin_family = AF_INET;
 			ia->ia_subnetmask =
@@ -497,7 +497,7 @@ in_control(struct socket *so, u_long cmd
 		}
 		if ((ifp->if_flags & IFF_POINTOPOINT) &&
 		    (ifra->ifra_dstaddr.sin_family == AF_INET)) {
-			in_ifscrub(ifp, ia, LLE_STATIC);
+			in_scrubprefix(ia, LLE_STATIC);
 			ia->ia_dstaddr = ifra->ifra_dstaddr;
 			maskIsNew  = 1; /* We lie; but the effect's the same */
 		}
@@ -523,9 +523,9 @@ in_control(struct socket *so, u_long cmd
 
 	case SIOCDIFADDR:
 		/*
-		 * in_ifscrub kills the interface route.
+		 * in_scrubprefix() kills the interface route.
 		 */
-		in_ifscrub(ifp, ia, LLE_STATIC);
+		in_scrubprefix(ia, LLE_STATIC);
 
 		/*
 		 * in_ifadown gets rid of all the rest of
@@ -771,16 +771,6 @@ in_lifaddr_ioctl(struct socket *so, u_lo
 }
 
 /*
- * Delete any existing route for an interface.
- */
-void
-in_ifscrub(struct ifnet *ifp, struct in_ifaddr *ia, u_int flags)
-{
-
-	in_scrubprefix(ia, flags);
-}
-
-/*
  * Initialize an interface's internet address
  * and routing table entry.
  */

Modified: head/sys/netinet/in_var.h
==============================================================================
--- head/sys/netinet/in_var.h	Fri Nov  1 10:01:57 2013	(r257498)
+++ head/sys/netinet/in_var.h	Fri Nov  1 10:18:41 2013	(r257499)
@@ -412,7 +412,6 @@ int	in_addprefix(struct in_ifaddr *, int
 int	in_scrubprefix(struct in_ifaddr *, u_int);
 void	ip_input(struct mbuf *);
 int	in_ifadown(struct ifaddr *ifa, int);
-void	in_ifscrub(struct ifnet *, struct in_ifaddr *, u_int);
 struct	mbuf	*ip_fastforward(struct mbuf *);
 void	*in_domifattach(struct ifnet *);
 void	in_domifdetach(struct ifnet *, void *);

Modified: head/sys/netinet/raw_ip.c
==============================================================================
--- head/sys/netinet/raw_ip.c	Fri Nov  1 10:01:57 2013	(r257498)
+++ head/sys/netinet/raw_ip.c	Fri Nov  1 10:18:41 2013	(r257499)
@@ -736,9 +736,9 @@ rip_ctlinput(int cmd, struct sockaddr *s
 				ifa_ref(&ia->ia_ifa);
 				IN_IFADDR_RUNLOCK();
 				/*
 				 * in_ifscrub kills the interface route.
 				 */
-				in_ifscrub(ia->ia_ifp, ia, 0);
+				in_scrubprefix(ia, 0);
 				/*
 				 * in_ifadown gets rid of all the rest of the
 				 * routes.  This is not quite the right thing
@@ -736,9 +736,9 @@ rip_ctlinput(int cmd, struct sockaddr *s
 				IN_IFADDR_RUNLOCK();
 				/*
-				 * in_ifscrub kills the interface route.
+				 * in_scrubprefix() kills the interface route.
 				 */


More information about the svn-src-all mailing list